@@ -26,7 +26,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: enable_pps.c,v 1.37 2000/03/11 16:45:58 windl Exp $
+ * $Id: enable_pps.c,v 1.38 2000/09/14 19:45:30 windl Exp $
  */
 #include	<unistd.h>
 #include	<stdlib.h>
@@ -84,7 +84,7 @@
 #define	BITS_OFF(v, b)			((v) & ~(b))
 #define	BITS_ON(v, b)			((v) | (b))
 
-static	const char	id[] = "$Id: enable_pps.c,v 1.37 2000/03/11 16:45:58 windl Exp $";
+static	const char	id[] = "$Id: enable_pps.c,v 1.38 2000/09/14 19:45:30 windl Exp $";
 
 #define	BIT(n)	(1UL << (n))
 #define OPT_MONITOR		BIT(0)	/* perform monitor loop */
@@ -100,7 +100,7 @@ static	const char	id[] = "$Id: enable_pps.c,v 1.37 2000/03/11 16:45:58 windl Exp
 
 static	unsigned long	options = OPT_MONITOR | OPT_RESET;
 
-static	char		trigger	= 'A';	/* off | assert | clear | both */
+static	char		trigger	= '0';	/* off | assert | clear | both */
 
 static	const	int	fd	= 0;	/* file descriptor of port (stdin) */
 static	pps_handle_t	ppshandle;	/* PPS handle (stdin) */
@@ -661,6 +661,7 @@ static	void	usage(void)
 #endif
 		"\t-S\tdon't adjust status in monitoring loop\n"
 		"\t-t{0|a|c|b}[h]\ttrigger for event: off|assert|clear|both\n"
+		"\t\t'h' = route to hardpps()\n"
 		);
 }
 
